@@ -1,6 +1,6 @@
 <?php
 
-/* * ******************************************
+/** ******************************************
  * LiteSpeed Web Server Cache Manager
  *
  * @author LiteSpeed Technologies, Inc. (https://www.litespeedtech.com)
@@ -34,7 +34,7 @@ abstract class ControlPanel
     /**
      * @var string
      */
-    const PANEL_API_VERSION = '1.9.7';
+    const PANEL_API_VERSION = '1.11';
 
     /**
      * @since 1.9
@@ -142,12 +142,36 @@ abstract class ControlPanel
      *
      * @deprecated
      * @param string  $className  A fully qualified control panel class name
+     * @return ControlPanel|null
      * @throws LSCMException
      */
     public static function initByClassName( $className )
     {
         if ( self::$instance == null ) {
 
+            if ( $className == 'custom' ) {
+                $lsws_home = realpath(__DIR__ . '/../../../../');
+                $customPanelFile = "{$lsws_home}/admin/lscdata/custom/CustomPanel.php";
+
+                if ( ! file_exists($customPanelFile)
+                        || ! include_once $customPanelFile ) {
+
+                    throw new LSCMException(
+                            "Unable to include file {$customPanelFile}");
+                }
+
+                $className = '\Lsc\Wp\Panel\CustomPanel';
+
+                $isSubClass =
+                        is_subclass_of($className, '\Lsc\Wp\Panel\CustomPanelBase');
+
+                if ( ! $isSubClass ) {
+                    $msg = 'Class CustomPanel must extend class '
+                            . '\Lsc\Wp\Panel\CustomPanelBase';
+                    throw new LSCMException($msg);
+                }
+            }
+
             try{
                 self::$instance = new $className();
             }
@@ -205,7 +229,7 @@ abstract class ControlPanel
      *
      * @param string $className  Fully qualified class name.
      * @return ControlPanel
-     * @throws LSCMException
+     * @throws LSCMException  Indirectly thrown by self::initByClassName().
      */
     public static function getClassInstance( $className = '' )
     {
@@ -227,7 +251,7 @@ abstract class ControlPanel
      */
     public static function getInstance()
     {
-        return $this->getClassInstance();
+        return self::getClassInstance();
     }
 
     /**
@@ -304,6 +328,8 @@ abstract class ControlPanel
     /**
      *
      * @param string  $vhCacheRoot
+     * @throws LSCMException  Indirectly thrown by $this->log() and
+     *                        $this->writeVHCacheRoot().
      */
     public function setVHCacheRoot( $vhCacheRoot = 'lscache' )
     {
@@ -553,6 +579,9 @@ abstract class ControlPanel
      *
      * @param string  $msg
      * @param int     $level
+     * @throws LSCMException  Indirectly thrown by Logger::error(),
+     *                        Logger::warn(), Logger::notice(), Logger::info(),
+     *                        Logger::verbose(), and Logger::debug().
      */
     protected function log( $msg, $level )
     {
@@ -661,7 +690,8 @@ abstract class ControlPanel
     /**
      *
      * @param string  $vhConf
-     * @throws LSCMException
+     * @throws LSCMException  Indirectly thrown by Util::createBackup() and
+     *                        $this->log().
      */
     public function writeVHCacheRoot( $vhConf, $vhCacheRoot = 'lscache' )
     {
@@ -809,13 +839,16 @@ abstract class ControlPanel
      *
      * @since 1.9
      *
-     * @param type $panelAPIVer  Shared code API version used by the panel
-     *                           plugin.
+     * @param string  $panelAPIVer  Shared code API version used by the panel
+     *                              plugin.
      * @return int
      */
     public static function checkPanelAPICompatibility( $panelAPIVer )
     {
         $supportedAPIVers = array (
+            '1.11',
+            '1.10',
+            '1.9.8',
             '1.9.7',
             '1.9.6.1',
             '1.9.6',
